@@ -84,7 +84,7 @@ BEGIN {
 with 'Log::LogMethods';
 with 'Data::Result::Moo';
 }
-our $VERSION='1.019';
+our $VERSION='1.020';
 
 sub BUILD {
   my ($self)=@_;
@@ -573,7 +573,9 @@ sub create_request {
     my $code=$self->que_function($req,$id);
     $opt->{cb}=$code;
   }
-  %{$opt}=(keepalive=>0,%{$opt});
+  foreach my $key (qw(keepalive persistent)) {
+    $opt->{params}->{$key}=0 unless exists $opt->{params}->{$key};
+  }
   my $request=$self->SENDER_CLASS->new(
     $req,
     $opt,
